# zimmauth

[![codeclimate](https://img.shields.io/codeclimate/maintainability/endremborza/zimmauth.svg)](https://codeclimate.com/github/endremborza/zimmauth)
[![codecov](https://img.shields.io/codecov/c/github/endremborza/zimmauth)](https://codecov.io/gh/endremborza/zimmauth)
[![pypi](https://img.shields.io/pypi/v/zimmauth.svg)](https://pypi.org/project/zimmauth/)

Encrypt and store authentication data for s3 and ssh.
